OciCommand

Enum OciCommand 

pub(crate) enum OciCommand {
Show 13 variants ImportLayer { digest: OciDigest, name: Option<String>, }, LsLayer { name: OciDigest, }, Dump { config_opts: OCIConfigFilesystemOptions, }, Pull { image: String, name: Option<String>, bootable: bool, local_fetch: LocalFetchCli, }, ListImages { json: bool, }, Inspect { image: OciReference, manifest: bool, config: bool, }, Tag { manifest_digest: OciDigest, name: String, }, Untag { name: String, }, LayerInspect { layer: OciDigest, dumpfile: bool, json: bool, }, Mount { image: String, mountpoint: String, bootable: bool, }, ComputeId { config_opts: OCIConfigFilesystemOptions, }, PrepareBoot { config_opts: OCIConfigOptions, bootdir: PathBuf, entry_id: Option<String>, cmdline: Vec<String>, }, Fsck { image: Option<String>, json: bool, },
}

Variants



ImportLayer

Import a tar layer as a splitstream in the repository

Fields

digest: OciDigest

Layer content digest, e.g. sha256:a1b2c3…

name: Option<String>

Optional human-readable name for the layer



LsLayer

List the contents of a stored tar layer

Fields

name: OciDigest

Layer content digest, e.g. sha256:a1b2c3…



Dump

Dump the rootfs of a stored OCI image as a composefs dumpfile to stdout

The image can be specified by ref name or @digest: cfsctl oci dump myimage:latest cfsctl oci dump @sha256:a1b2c3…

Fields



Pull

Pull an OCI image into the repository

Prints the config stream digest and verity of the stored manifest.

Fields

image: String

Source image reference, as accepted by skopeo

name: Option<String>

Tag name to assign to the pulled image (defaults to the image reference)

bootable: bool

Also generate a bootable EROFS image from the pulled OCI image

local_fetch: LocalFetchCli

Controls whether containers-storage: references use the native import path with zero-copy reflink/hardlink support.



ListImages

List all tagged OCI images in the repository

Fields

json: bool

Output as JSON array



Inspect

Show information about an OCI image

The image can be specified by ref name or @digest: cfsctl oci inspect myimage:latest cfsctl oci inspect @sha256:a1b2c3…

By default, outputs JSON with manifest, config, and referrers. Use –manifest or –config to output just that raw JSON.

Fields

image: OciReference

Ref name (e.g. myimage:latest) or @digest (e.g. @sha256:a1b2c3…)

manifest: bool

Output only the raw manifest JSON (as originally stored)

config: bool

Output only the raw config JSON (as originally stored)



Tag

Tag an image with a new name

Example: cfsctl oci tag sha256:a1b2c3… myimage:latest

Fields

manifest_digest: OciDigest

Manifest digest, e.g. sha256:a1b2c3…

name: String

Tag name to assign (must not contain ‘@’)



Untag

Remove a tag from an image

Fields

name: String

Tag name to remove



LayerInspect

Inspect a stored layer

By default, outputs the raw tar stream to stdout. Use –dumpfile for composefs dumpfile format, or –json for metadata.

Fields

layer: OciDigest

Layer diff_id, e.g. sha256:a1b2c3…

dumpfile: bool

Output as composefs dumpfile format (one entry per line)

json: bool

Output layer metadata as JSON



Mount

Mount an OCI image’s composefs EROFS at the given mountpoint

Fields

image: String

Image reference (tag name or manifest digest)

mountpoint: String

Target mountpoint

bootable: bool

Mount the bootable variant instead of the regular EROFS image



ComputeId

Compute the composefs image ID of a stored OCI image’s rootfs

The image can be specified by ref name or @digest: cfsctl oci compute-id myimage:latest cfsctl oci compute-id @sha256:a1b2c3…

Fields



PrepareBoot

Create the composefs image of the rootfs of a stored OCI image, perform bootable transformation, commit it to the repo, then configure boot for the image by writing new boot resources and bootloader entries to boot partition. Performs state preparation for composefs-setup-root consumption as well. Note that state preparation here is not suitable for consumption by bootc.

Fields

config_opts: OCIConfigOptions
bootdir: PathBuf

boot partition mount point

entry_id: Option<String>

Boot entry identifier to use. By default uses ID provided by the image or kernel version

cmdline: Vec<String>

additional kernel command line



Fsck

Check integrity of OCI images in the repository

Verifies manifest and config content digests, layer references, seal consistency, and delegates to the underlying repository fsck for object integrity and splitstream validation.

Fields

image: Option<String>

Check only the named image instead of all tagged images

json: bool

Output results as JSON (always exits 0 unless the check itself fails)