pub(crate) enum OstreeCommand {
PullLocal {
ostree_repo_path: PathBuf,
ostree_ref: String,
base_name: Option<String>,
},
Pull {
ostree_repo_url: String,
ostree_ref: String,
base_name: Option<String>,
},
Mount {
commit: String,
mountpoint: String,
upperdir: Option<PathBuf>,
workdir: Option<PathBuf>,
read_write: bool,
},
Dump {
commit_name: String,
},
ComputeId {
commit_name: String,
},
Inspect {
source: String,
metadata: bool,
},
Tag {
source: String,
name: String,
},
Untag {
name: String,
},
ListCommits,
}Variants
PullLocal
Fields
Pull
Fields
Mount
Mount an ostree commit’s composefs EROFS at the given mountpoint
Fields
Dump
Dump the filesystem of an ostree commit as a composefs dumpfile to stdout
ComputeId
Compute the composefs image ID of an ostree commit
Inspect
Show the contents of an ostree commit
Fields
Tag
Tag an ostree commit with a name
The source can be an ostree commit checksum or an existing ref name.
Fields
Untag
Remove a named ostree reference
ListCommits
List all ostree commits in the repository