pub struct App {
pub(crate) repo: Option<PathBuf>,
pub(crate) user: bool,
pub(crate) system: bool,
pub hash: Option<HashType>,
pub erofs_version: Option<ErofsVersion>,
pub(crate) insecure: bool,
pub(crate) require_verity: bool,
pub(crate) no_upgrade: bool,
pub no_repo: bool,
pub(crate) cmd: Command,
}Expand description
cfsctl
Fields
repo: Option<PathBuf>Operate on repo at path
user: boolOperate on repo at standard user location $HOME/.var/lib/composefs
system: boolOperate on repo at standard system location /sysroot/composefs
hash: Option<HashType>What hash digest type to use for composefs repo. If omitted, auto-detected from repository metadata (meta.json).
erofs_version: Option<ErofsVersion>The EROFS format version to use when generating images. If omitted, the library default (V2) is used.
insecure: boolDeprecated: security mode is now auto-detected from meta.json.
Use cfsctl init --insecure to create a repo without verity.
Kept for backward compatibility.
require_verity: boolError if the repository does not have fs-verity enabled.
no_upgrade: boolDon’t automatically upgrade old-format repositories. When set, commands will fail on repos without meta.json instead of inferring metadata from existing objects.
no_repo: boolDon’t open a repository. Only valid for commands that don’t need one (compute-id, create-dumpfile).
cmd: CommandTrait Implementations
Sourceimpl Args for App
impl Args for App
Sourcefn group_id() -> Option<Id>
fn group_id() -> Option<Id>
ArgGroup::id][crate::ArgGroup::id] for this set of argumentsSourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command] so it can instantiate self via
[FromArgMatches::update_from_arg_matches_mut] Read moreSourceimpl FromArgMatches for App
impl FromArgMatches for App
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for App
impl Parser for App
fn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>