pub(crate) enum OciCommand {
Show 13 variants
ImportLayer {
digest: OciDigest,
name: Option<String>,
},
LsLayer {
name: OciDigest,
},
Dump {
config_opts: OCIConfigFilesystemOptions,
},
Pull {
image: String,
name: Option<String>,
bootable: bool,
local_fetch: LocalFetchCli,
},
ListImages {
json: bool,
},
Inspect {
image: OciReference,
manifest: bool,
config: bool,
},
Tag {
manifest_digest: OciDigest,
name: String,
},
Untag {
name: String,
},
LayerInspect {
layer: OciDigest,
dumpfile: bool,
json: bool,
},
Mount {
image: String,
mountpoint: String,
bootable: bool,
},
ComputeId {
config_opts: OCIConfigFilesystemOptions,
},
PrepareBoot {
config_opts: OCIConfigOptions,
bootdir: PathBuf,
entry_id: Option<String>,
cmdline: Vec<String>,
},
Fsck {
image: Option<String>,
json: bool,
},
}Variants
ImportLayer
Import a tar layer as a splitstream in the repository
Fields
digest: OciDigestLayer content digest, e.g. sha256:a1b2c3…
LsLayer
List the contents of a stored tar layer
Fields
name: OciDigestLayer content digest, e.g. sha256:a1b2c3…
Dump
Dump the rootfs of a stored OCI image as a composefs dumpfile to stdout
The image can be specified by ref name or @digest: cfsctl oci dump myimage:latest cfsctl oci dump @sha256:a1b2c3…
Fields
config_opts: OCIConfigFilesystemOptionsPull
Pull an OCI image into the repository
Prints the config stream digest and verity of the stored manifest.
Fields
local_fetch: LocalFetchCliControls whether containers-storage: references use the native import path with zero-copy reflink/hardlink support.
ListImages
List all tagged OCI images in the repository
Inspect
Show information about an OCI image
The image can be specified by ref name or @digest: cfsctl oci inspect myimage:latest cfsctl oci inspect @sha256:a1b2c3…
By default, outputs JSON with manifest, config, and referrers. Use –manifest or –config to output just that raw JSON.
Fields
image: OciReferenceRef name (e.g. myimage:latest) or @digest (e.g. @sha256:a1b2c3…)
Tag
Tag an image with a new name
Example: cfsctl oci tag sha256:a1b2c3… myimage:latest
Fields
manifest_digest: OciDigestManifest digest, e.g. sha256:a1b2c3…
Untag
Remove a tag from an image
LayerInspect
Inspect a stored layer
By default, outputs the raw tar stream to stdout. Use –dumpfile for composefs dumpfile format, or –json for metadata.
Fields
layer: OciDigestLayer diff_id, e.g. sha256:a1b2c3…
Mount
Mount an OCI image’s composefs EROFS at the given mountpoint
Fields
ComputeId
Compute the composefs image ID of a stored OCI image’s rootfs
The image can be specified by ref name or @digest: cfsctl oci compute-id myimage:latest cfsctl oci compute-id @sha256:a1b2c3…
Fields
config_opts: OCIConfigFilesystemOptionsPrepareBoot
Create the composefs image of the rootfs of a stored OCI image, perform bootable transformation, commit it to the repo, then configure boot for the image by writing new boot resources and bootloader entries to boot partition. Performs state preparation for composefs-setup-root consumption as well. Note that state preparation here is not suitable for consumption by bootc.
Fields
config_opts: OCIConfigOptionsFsck
Check integrity of OCI images in the repository
Verifies manifest and config content digests, layer references, seal consistency, and delegates to the underlying repository fsck for object integrity and splitstream validation.