pub(crate) fn resolve_oci_config<ObjectID: FsVerityHashValue>(
repo: &Repository<ObjectID>,
reference: &OciReference,
verity_override: Option<ObjectID>,
) -> Result<(OciDigest, Option<ObjectID>)>Expand description
Resolve an OciReference to a config digest and optional verity.
When resolving via a named ref, the verity override is ignored since the image metadata provides the correct verity.